# apswduapi.py
# Copyright (c) 2015 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""
A database API for bulk insertion of records, implemented using apsw,
where indicies are represented as lists or bitmaps of record numbers.
    
apsw is an interface to SQLite3.

The database is accessed as if made from Berkeley DB primary and secondary
databases.

The Sqlite3duPrimary and Sqlite3duSecondary classes imported from the _sqlitedu
module provide the behaviour.

"""

from .apswapi import (
    Sqlite3base,
    )
from ._sqlitedu import (
    Sqlite3duapi,
    Sqlite3duPrimary,
    Sqlite3duSecondary,
    Sqlite3duapiError, # For the benefit of subclasses of Sqlite3base.
    )


class Sqlite3duapi(Sqlite3duapi, Sqlite3base):
    
    """Access database with apsw.  See superclass for *args and **kargs.
    
    apsw is an interface to SQLite3.
    
    Sqlite3duPrimary instances are used to do bulk data insertions, and
    Sqlite3duSecondary instances are used to update indicies for the bulk
    data insertions.

    There will be one Sqlite3duPrimary instance for each SQLite3 table, used
    approximately like a Berkeley DB primary database.

    There will be one Sqlite3duSecondary instance for each SQLite3 index, used
    approximately like a Berkeley DB secondary database.

    Primary and secondary terminology comes from Berkeley DB documentation.
    
    """

    def __init__(self, database_specification, *args, **kargs):
        """Use Sqlite3duPrimary and Sqlite3duSecondary classes."""
        super(Sqlite3duapi, self).__init__(
            Sqlite3duPrimary,
            Sqlite3duSecondary,
            database_specification,
            *args,
            **kargs)
