# sqlite3api.py
# Copyright 2011 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""
A database API, implemented using sqlite3, where indicies are represented as
lists or bitmaps of record numbers.
    
sqlite3 is an interface to SQLite3.

The database is accessed as if made from Berkeley DB primary and secondary
databases.

The Sqlite3Primary and Sqlite3Secondary classes imported from the _sqlite
module provide the behaviour.

"""

import sqlite3

from ._sqlite import (
    Sqlite3apiError, # For the benefit of subclasses of Sqlite3base.
    Sqlite3base,
    Sqlite3api,
    Sqlite3Primary,
    Sqlite3Secondary,
    )


class Sqlite3base(Sqlite3base):
    
    """Use sqlite3 module to access SQLite3 databases."""

    def make_connection(self):
        """Connect to an SQLite3 database with sqlite3 module."""
        if self._sqconn is None:
            self._sqconn = sqlite3.Connection(self._home)
            # Remove the following statement to convert to unicode strings
            #self._sqconn.text_factory = str


class Sqlite3api(Sqlite3api, Sqlite3base):
    
    """Access database with sqlite3.  See superclass for *args and **kargs.
    
    sqlite3 is an interface to SQLite3.
    
    Sqlite3Primary instances are used to access data, and Sqlite3Secondary
    instances are used to access indicies on the data.

    There will be one Sqlite3Primary instance for each SQLite3 table, used
    approximately like a Berkeley DB primary database.

    There will be one Sqlite3Secondary instance for each SQLite3 index, used
    approximately like a Berkeley DB secondary database.

    Primary and secondary terminology comes from Berkeley DB documentation.
    
    """

    def __init__(self, database_specification, *args, **kargs):
        """Use Sqlite3Primary and Sqlite3Secondary classes."""
        super().__init__(
            Sqlite3Primary,
            Sqlite3Secondary,
            database_specification,
            *args,
            **kargs)
